FineOffset - WeeWX 5.0
Author: Tom Keffer <tkeffer@gmail.com>

Skip to content

# FineOffset (USB)

The station clock can only be set manually via buttons on the console, or (if the station supports it) by WWVB radio. The FineOffsetUSB driver ignores the station clock since it cannot be trusted.

The station reads data from the sensors every 48 seconds. The 30xx stations read UV data every 60 seconds.

The 10xx and 20xx stations can save up to 4080 historical readings. That is about 85 days of data with the default recording interval of 30 minutes, or about 14 days with a recording interval of 5 minutes. The 30xx stations can save up to 3264 historical readings.

When WeeWX starts up it will attempt to download all records from the console since the last record in the archive database.

## Polling mode and interval

When reading 'live' data, WeeWX can read as fast as possible, or at a user-defined period. This is controlled by the option `polling_mode` in the WeeWX configuration file.

Polling modes for Fine Offset stations
Mode | Configuration | Notes
ADAPTIVE |
    [FineOffsetUSB]
    polling_mode = ADAPTIVE
| In this mode, WeeWX reads data from the station as often as possible, but at intervals that avoid communication between the console and the sensors. Nominally this results in reading data every 48 seconds.
PERIODIC |
    [FineOffsetUSB]
    polling_mode = PERIODIC
    polling_interval = 60
| In this mode, WeeWX reads data from the station every polling_interval seconds. The console reads the sensors every 48 seconds (60 seconds for UV), so setting the polling_interval to a value less than 48 will result in duplicate readings.

## Data format

The 10xx/20xx consoles have a data format that is different from the 30xx consoles. All of the consoles recognize wind, rain, temperature, and humidity from the same instrument clusters. However, some instrument clusters also include a luminosity sensor. Only the 30xx consoles recognize the luminosity and UV output from these sensors. As a consequence, the 30xx consoles also have a different data format.

Since WeeWX cannot reliably determine the data format by communicating with the station, the `data_format` configuration option indicates the station type. Possible values are `1080` and `3080`. Use `1080` for the 10xx and 20xx consoles.

The default value is `1080`.

For example, this would indicate that the station is a 30xx console:

    [FineOffsetUSB]
        data_format = 3080

## Configuring with `weectl device`

Note

Make sure you stop `weewxd` before running `weectl device`.

### `--help`

Invoking `weectl device` with the `--help` option

    weectl device --help

will produce something like this:

    FineOffsetUSB driver version 1.7
    Usage: weectl device [config_file] [options] [--debug] [--help]

    Configuration utility for weewx devices.

    Options:
    -h, --help           show this help message and exit
    --debug              display diagnostic information while running
    -y                   answer yes to every prompt
    --info               display weather station configuration
    --current            get the current weather conditions
    --history=N          display N records
    --history-since=N    display records since N minutes ago
    --clear-memory       clear station memory
    --set-time           set station clock to computer time
    --set-interval=N     set logging interval to N minutes
    --live               display live readings from the station
    --logged             display logged readings from the station
    --fixed-block        display the contents of the fixed block
    --check-usb          test the quality of the USB connection
    --check-fixed-block  monitor the contents of the fixed block
    --format=FORMAT      format for output, one of raw, table, or dict

    Mutating actions will request confirmation before proceeding.

### `--info`

Display the station settings with the `--info` option.

    weectl device --info

This will result in something like:

    Fine Offset station settings:
    local time: 2013.02.11 18:34:28 CET
    polling_mode: ADAPTIVE

    abs_pressure: 933.3
    current_pos: 592
    data_changed: 0
    data_count: 22
    date_time: 2007-01-01 22:49
    hum_in_offset: 18722
    hum_out_offset: 257
    id: None
    lux_wm2_coeff: 0
    magic_1: 0x55
    magic_2: 0xaa
    model: None
    rain_coef: None
    read_period: 30
    rel_pressure: 1014.8
    temp_in_offset: 1792
    temp_out_offset: 0
    timezone: 0
    unknown_01: 0
    unknown_18: 0
    version: 255
    wind_coef: None
    wind_mult: 0

Highlighted values can be modified.

### `--set-interval=N`

Set the archive interval. Fine Offset stations ship from the factory with an archive interval (read_period) of 30 minutes (1800 seconds). To change the station's interval to 5 minutes, do the following:

    weectl device --set-interval=5

### `--history=N`

Fine Offset stations store records in a circular buffer — once the buffer fills, the oldest records are replaced by newer records. The 1080 and 2080 consoles store up to 4080 records. The 3080 consoles store up to 3264 records. The `data_count` indicates how many records are in memory. The `read_period` indicates the number of minutes between records. `weectl device` can display these records in space-delimited, raw bytes, or dictionary format.

For example, to display the most recent 30 records from the console memory:

    weectl device --history=30

### `--clear-memory`

To clear the console memory:

    weectl device --clear-memory

### `--check-usb`

This command can test the quality of the USB connection between the computer and console. Poor quality USB cables, under-powered USB hubs, and other devices on the bus can interfere with communication.

To test the quality of the USB connection to the console:

    weectl device --check-usb

Let the utility run for at least a few minutes, or possibly an hour or two. It is not unusual to see a few bad reads in an hour, but if you see many bad reads within a few minutes, consider replacing the USB cable, USB hub, or removing other devices from the bus.

## Station data

The following table shows which data are provided by the station hardware and which are calculated by WeeWX.

Fine Offset station data
Database Field | Observation | Loop | Archive
barometer |  | S | S
pressure | pressure | H | H
altimeter |  | S | S
inTemp | temperature_in | H | H
outTemp | temperature_out | H | H
inHumidity | humidity_in | H | H
outHumidity | humidity_out | H | H
windSpeed | wind_speed | H | H
windDir | wind_dir | H | H
windGust | wind_gust | H | H
rain | rain | D | D
| rain_total | H | H
rainRate |  | S | S
dewpoint | dewpoint | H | S
windchill | windchill | H | S
heatindex | heatindex | H | S
radiation1 | radiation | D | D
luminosity1 | luminosity | H | H
rxCheckPercent | signal | H |
outTempBatteryStatus | battery | H |

1 The radiation data are available only from 30xx stations. These stations include a luminosity sensor, from which the radiation is approximated.

H indicates data provided by Hardware
D indicates data calculated by the Driver
S indicates data calculated by the StdWXCalculate Service